aboutsummaryrefslogtreecommitdiff
path: root/gcc/testsuite
diff options
context:
space:
mode:
authorZack Weinberg <zack@gcc.gnu.org>2003-07-05 00:24:00 +0000
committerZack Weinberg <zack@gcc.gnu.org>2003-07-05 00:24:00 +0000
commite6cc3a24c237713413070f4a5dc35b55dc2715b8 (patch)
tree34c7734f7acee49beff2b3d99cbdf53576456697 /gcc/testsuite
parent61aeb06fe596bd822b665d65a271804efdaf0053 (diff)
downloadgcc-e6cc3a24c237713413070f4a5dc35b55dc2715b8.zip
gcc-e6cc3a24c237713413070f4a5dc35b55dc2715b8.tar.gz
gcc-e6cc3a24c237713413070f4a5dc35b55dc2715b8.tar.bz2
cpplib.h (CPP_AT_NAME, [...]): New token types.
* cpplib.h (CPP_AT_NAME, CPP_OBJC_STRING): New token types. (struct cpp_options): Add narrow_charset, wide_charset, bytes_big_endian fields. Remove EBCDIC field. (cpp_init_iconv, cpp_interpret_string): New external interfaces. * cpphash.h: Include <iconv.h> if we have it, otherwise provide a dummy definition of iconv_t. (struct cpp_reader): Add narrow_cset_desc and wide_cset_desc fields. (_cpp_valid_ucn): Update prototype. (_cpp_destroy_iconv): New prototype. * doc/cpp.texi: Document character set handling. * doc/cppopts.texi: Document -fexec-charset= and -fexec-wide-charset=. * doc/extend.texi: Delete entire section on multiline strings. Rewrite section on __FUNCTION__ etc now that these are variables in C. * cppucnid.tab, cppucnid.pl: New files. * cppucnid.h: New generated file. * cppcharset.c: Include cppucnid.h. Lots of commentary added. (iconv_open, iconv, iconv_close): Provide dummy definitions if !HAVE_ICONV. (SOURCE_CHARSET, struct strbuf, init_iconv_desc, cpp_init_iconv, _cpp_destroy_iconv, convert_cset, width_to_mask, convert_ucn, emit_numeric_escape, convert_hex, convert_oct, convert_escape, cpp_interpret_string, narrow_str_to_charconst, wide_str_to_charconst): New. (ucn_valid_in_identifier): Use a binary search through the ucnranges table defined in cppucnid.h, not a long chain of if statements. (_cpp_valid_ucn): Add a limit pointer. Downgrade "universal character names are only valid in C++ and C99" to a warning. Issue the "meaning of \[uU] is different in traditional C" warning here. Take care not to let iconv see an invalid UCS value if we get a malformed UCN. Issue an error if we don't have iconv. (cpp_interpret_charconst): Moved here from cpplex.c. Use cpp_interpret_string to do the heavy lifting. * cppinit.c (cpp_create_reader): Initialize bytes_big_endian, narrow_charset, wide_charset fields of options structure. (cpp_destroy): Call _cpp_destroy_iconv. * cpplex.c (forms_identifier_p): Adjust call to _cpp_valid_ucn. (maybe_read_ucn, hex_digit_value, cpp_parse_escape): Delete. (cpp_interpret_charconst): Moved to cppcharset.c. * cpplib.c (dequote_string): Delete. (interpret_string_notranslate): New. (do_line, do_linemarker): Use interpret_string_notranslate. * Makefile.in (cppcharset.o): Depend on cppucnid.h. * c-common.c (fname_string, combine_strings): Delete. * c-common.h (fname_string, combine_strings): Delete prototypes. * c-lex.c (ignore_escape_flag): Delete. (cb_ident): Use cpp_interpret_string, not lex_string. (get_nonpadding_token): New function. (c_lex): Handle Objective-C @-prefixed identifiers and strings here. Adjust calls to lex_string. Don't write *value twice. (lex_string): Now handles string constant concatenation. Most of the work handed off to cpp_interpret_string. Call fix_string_type here. * c-parse.in (STRING_FUNC_NAME, VAR_FUNC_NAME): Replace with FUNC_NAME, throughout. (OBJC_STRING): New token type. (primary:STRING): No need to call fix_string_type here. (primary:objc_string): Make that OBJC_STRING. (objc_string nonterminal): Delete. (yylexname): Delete code to handle fake string constants. (yylexstring): Delete entirely. (_yylex): Handle CPP_AT_NAME and CPP_OBJC_STRING. No need to handle CPP_ATSIGN. * c.opt (-fexec-charset=, -fwide-exec-charset=): New options. * c-opts.c (missing_arg, c_common_handle_option): Handle OPT_fexec_charset_ and OPT_fwide_exec_charset_. (c_common_init): Set cpp_opts->bytes_big_endian, not cpp_opts->EBCDIC. Call cpp_init_iconv. (print_help): Document -fexec-charset= and -fexec-wide-charset=. (TARGET_EBCDIC): Delete default definition. * objc/objc-act.c (build_objc_string_object): No need to handle string constant concatenation. cp: * parser.c (cp_lexer_read_token): No need to handle string constant concatenation. testsuite: * gcc.c-torture/execute/wchar_t-1.x: New file; XFAIL wchar_t-1.c everywhere. * gcc.dg/concat.c: Concatenation of string constants with __FUNCTION__ / __PRETTY_FUNCTION__ is now a hard error. * gcc.dg/wtr-strcat-1.c: Loosen dg-warning regexp. * gcc.dg/cpp/escape-2.c: Use wide character constants where necessary to avoid multi-character character constant warning. * gcc.dg/cpp/escape.c: Likewise. * gcc.dg/cpp/ucs.c: Likewise. Remove backslashes from dg-bogus comments, as they confuse Tcl. Fix a typo. libstdc++-v3: * testsuite/22_locale/collate/compare/wchar_t/2.cc * testsuite/22_locale/collate/compare/wchar_t/wrapped_env.cc * testsuite/22_locale/collate/compare/wchar_t/wrapped_locale.cc * testsuite/22_locale/collate/hash/wchar_t/2.cc * testsuite/22_locale/collate/hash/wchar_t/wrapped_env.cc * testsuite/22_locale/collate/hash/wchar_t/wrapped_locale.cc * testsuite/22_locale/collate/transform/wchar_t/2.cc * testsuite/22_locale/collate/transform/wchar_t/wrapped_env.cc * testsuite/22_locale/collate/transform/wchar_t/wrapped_locale.cc: XFAIL on all targets. From-SVN: r68952
Diffstat (limited to 'gcc/testsuite')
-rw-r--r--gcc/testsuite/ChangeLog110
-rw-r--r--gcc/testsuite/gcc.c-torture/execute/wchar_t-1.x3
-rw-r--r--gcc/testsuite/gcc.dg/concat.c12
-rw-r--r--gcc/testsuite/gcc.dg/cpp/escape-2.c4
-rw-r--r--gcc/testsuite/gcc.dg/cpp/escape.c4
-rw-r--r--gcc/testsuite/gcc.dg/cpp/ucs.c8
-rw-r--r--gcc/testsuite/gcc.dg/wtr-strcat-1.c2
7 files changed, 80 insertions, 63 deletions
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 3079c34..d67d0b7 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,17 @@
+2003-07-04 Zack Weinberg <zack@codesourcery.com>
+
+ * gcc.c-torture/execute/wchar_t-1.x: New file; XFAIL wchar_t-1.c
+ everywhere.
+ * gcc.dg/concat.c: Concatenation of string constants with
+ __FUNCTION__ / __PRETTY_FUNCTION__ is now a hard error.
+ * gcc.dg/wtr-strcat-1.c: Loosen dg-warning regexp.
+ * gcc.dg/cpp/escape-2.c: Use wide character constants where
+ necessary to avoid multi-character character constant warning.
+ * gcc.dg/cpp/escape.c: Likewise.
+ * gcc.dg/cpp/ucs.c: Likewise.
+ Remove backslashes from dg-bogus comments, as they confuse Tcl.
+ Fix a typo.
+
2003-07-04 Kazu Hirata <kazu@cs.umass.edu>
PR c/11428
@@ -117,7 +131,7 @@
PR c++/10219
* g++.dg/template/error1.C: New.
-
+
PR c++/9779
* g++.dg/template/dependent-expr1.C: New.
@@ -131,8 +145,8 @@
2003-07-01 Giovanni Bajo <giovannibajo@libero.it>
- PR c++/8046
- * g++.dg/other/error7.C: New test.
+ PR c++/8046
+ * g++.dg/other/error7.C: New test.
2003-07-01 Kazu Hirata <kazu@cs.umass.edu>
@@ -164,22 +178,22 @@
2003-06-30 Giovanni Bajo <giovannibajo@libero.it>
- PR c++/4933
- * g++.dg/template/sizeof4.C: New test.
+ PR c++/4933
+ * g++.dg/template/sizeof4.C: New test.
2003-06-30 Giovanni Bajo <giovannibajo@libero.it>
- * g++.dg/other/error6.C: New test.
+ * g++.dg/other/error6.C: New test.
2003-06-30 Giovanni Bajo <giovannibajo@libero.it>
- PR c++/10750
- * g++.dg/parse/constant2.C: New test.
+ PR c++/10750
+ * g++.dg/parse/constant2.C: New test.
2003-06-30 Giovanni Bajo <giovannibajo@libero.it>
- PR c++/11106
- * g++.dg/other/error5.C: New test.
+ PR c++/11106
+ * g++.dg/other/error5.C: New test.
2003-06-29 Kaveh R. Ghazi <ghazi@caip.rutgers.edu>
@@ -238,8 +252,8 @@
2003-06-26 Giovanni Bajo <giovannibajo@libero.it>
- PR c++/8266
- * g++.dg/template/explicit-instantiation3.C: New test.
+ PR c++/8266
+ * g++.dg/template/explicit-instantiation3.C: New test.
2003-06-26 Eric Botcazou <ebotcazou@libertysurf.fr>
@@ -263,7 +277,7 @@
PR c++/10931
* g++.dg/expr/static_cast1.C: New test.
-
+
2003-06-25 Josef Zlomek <zlomekj@suse.cz>
* gcc.dg/20030625-1.c: New test.
@@ -295,10 +309,10 @@
2003-06-21 Gabriel Dos Reis <gdr@integrable-solutions.net>
- * g++.old-deja/g++.benjamin/16077.C: Add -Wconversion option.
- * g++.old-deja/g++.other/conv7.C: Likewise
- * g++.old-deja/g++.other/overcnv2.C: Likewise.
- * g++.old-deja/g++.other/overload14.C: Likewise.
+ * g++.old-deja/g++.benjamin/16077.C: Add -Wconversion option.
+ * g++.old-deja/g++.other/conv7.C: Likewise
+ * g++.old-deja/g++.other/overcnv2.C: Likewise.
+ * g++.old-deja/g++.other/overload14.C: Likewise.
2003-06-21 Gabriel Dos Reis <gdr@integrable-solutions.net>
@@ -308,7 +322,7 @@
2003-06-20 Mark Mitchell <mark@codesourcery.com>
PR c++/10888
- * g++.dg/warn/Winline-3.C: New test.
+ * g++.dg/warn/Winline-3.C: New test.
2003-06-20 Mark Mitchell <mark@codesourcery.com>
@@ -319,8 +333,8 @@
* g++.dg/template/memclass2.C: New test.
2003-06-20 Mark Mitchell <mark@codesourcery.com>
- Eric Botcazou <ebotcazou@libertysurf.fr>
-
+ Eric Botcazou <ebotcazou@libertysurf.fr>
+
* lib/gcc-dg.exp (dg-xfail-if): Do not process conditional xfail
data for non-matching targets.
* gcc.c-torture/compile/simd-5.c: Fix typo in conditional xfail.
@@ -349,7 +363,7 @@
* g++.dg/anew2.C: New test.
* g++.dg/anew3.C: New test.
* g++.dg/anew4.C: New test.
-
+
2003-06-19 Kazu Hirata <kazu@cs.umass.edu>
* gcc.c-torture/compile/simd-5.c: Don't XFAIL on H8.
@@ -363,7 +377,7 @@
* lib/g++.exp (g++_include_flags): Tweak path to testsuite_flags.
Remove cruft.
-
+
2003-06-17 Kazu Hirata <kazu@cs.umass.edu>
* gcc.c-torture/compile/20020604-1.c: Use dg-xfail-if for h8300.
@@ -374,7 +388,7 @@
PR c++/10712
* g++.dg/lookup/using7.C: New test.
-
+
2003-06-17 Mark Mitchell <mark@codesourcery.com>
PR c++/11105
@@ -444,7 +458,7 @@
(dg-xfail-if): Likewise.
* gcc.c-torture/compile/compile.exp: Use dg rather than c-torture
driver.
-
+
* gcc.c-torture/compile/20000804-1.c: Convert to dg format.
* gcc.c-torture/compile/20001205-1.c: Likewise.
* gcc.c-torture/compile/20001226-1.c: Likewise.
@@ -775,7 +789,7 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
* lib/g++.exp (additional_sources): Remove.
(additional_files): Likewise.
(g++_target_compile): Use dg-additional-files-options.
-
+
* gcc.dg/special/special.exp: Add "ecos" tests. Remove complex
Tcl logic.
* gcc.dg/special/ecos.exp: Remove.
@@ -787,7 +801,7 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
* gcc.dg/special/weak-2.c: Likewise.
* gcc.dg/special/wkali-1.c: Likewise.
* gcc.dg/special/wkali-2.c: Likewise.
-
+
* g++.dg/special/conpr-2.C: Use dg-additional-*, not
dg-gpp-additional-*.
* g++.dg/special/conpr-3.C: Likewise.
@@ -819,13 +833,13 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
2003-06-04 Richard Henderson <rth@redhat.com>
- * gcc.dg/cleanup-1.c: New.
- * gcc.dg/cleanup-2.c: New.
- * gcc.dg/cleanup-3.c: New.
- * gcc.dg/cleanup-4.c: New.
- * gcc.dg/cleanup-5.c: New.
- * gcc.dg/cleanup-6.c: New.
- * gcc.dg/cleanup-7.c: New.
+ * gcc.dg/cleanup-1.c: New.
+ * gcc.dg/cleanup-2.c: New.
+ * gcc.dg/cleanup-3.c: New.
+ * gcc.dg/cleanup-4.c: New.
+ * gcc.dg/cleanup-5.c: New.
+ * gcc.dg/cleanup-6.c: New.
+ * gcc.dg/cleanup-7.c: New.
2003-06-04 Mark Mitchell <mark@codesourcery.com>
@@ -866,7 +880,7 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
2003-06-03 Aldy Hernandez <aldyh@redhat.com>
- * gcc.c-torture/compile/simd-5.x: Remove xfail for PPC64.
+ * gcc.c-torture/compile/simd-5.x: Remove xfail for PPC64.
2003-06-03 Kriang Lerdsuwanakij <lerdsuwa@users.sourceforge.net>
@@ -934,7 +948,7 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
* gcc.dg/cpp/cpp.exp: Remove scanning of ".cpp" files.
2003-06-01 Loren James Rittle <ljrittle@acm.org>
-
+
* gcc.dg/cpp/redef3.c: New file.
2003-06-01 Eric Botcazou <ebotcazou@libertysurf.fr>
@@ -964,7 +978,7 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
PR fortran/10843
* g77.dg/ffixed-form-1.f: New test
* g77.dg/ffixed-form-2.f: New test
- * g77.dg/ffree-form-2.f: New test - XFAIL pending fix
+ * g77.dg/ffree-form-2.f: New test - XFAIL pending fix
* g77.dg/ffree-form-3.f: New test
2003-05-26 Andreas Tobler <a.tobler@schweiz.ch>
@@ -982,21 +996,21 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
* g++.dg/template/access10.C: New test.
2003-05-24 Eric Botcazou <ebotcazou@libertysurf.fr>
- Kaveh R. Ghazi <ghazi@caip.rutgers.edu>
+ Kaveh R. Ghazi <ghazi@caip.rutgers.edu>
* gcc.c-torture/compile/simd-5.x: XFAIL on SPARC64.
2003-05-24 Andreas Tobler <a.tobler@schweiz.ch>
- * gcc.dg/torture/builtin-noret-1.c: Add dg-option -multiply_defined
- suppress for powerpc-*-darwin*.
+ * gcc.dg/torture/builtin-noret-1.c: Add dg-option -multiply_defined
+ suppress for powerpc-*-darwin*.
* gcc.dg/torture/builtin-noret-2.c: Likewise.
2003-05-24 Andreas Tobler <a.tobler@schweiz.ch>
* gcc.c-torture/execute/builtins/builtins.exp: Add -multiply_defined
suppress option for powerpc-*-darwin*.
-
+
2003-05-23 Roger Sayle <roger@eyesopen.com>
* gcc.dg/builtins-1.c: Add tests for tan and atan.
@@ -1123,7 +1137,7 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
* lib/g++-dg.exp: Use gcc-dg.exp to implement all functionality.
* lib/g77-dg.exp: Likewise.
* lib/obj-dg.exp: Likewise.
-
+
2003-05-16 Jakub Jelinek <jakub@redhat.com>
Merge from gcc-3_2-rhl8-branch:
@@ -1316,13 +1330,13 @@ Sun Jun 8 16:46:04 CEST 2003 Jan Hubicka <jh@suse.cz>
2003-05-07 Richard Henderson <rth@redhat.com>
- PR c++/10570
- * g++.dg/eh/forced1.C: Expect catch-all handlers to run.
- Verify exception_cleanup not called for rethrows.
- * g++.dg/eh/forced2.C: Test that exception_cleanup is called
- when exiting catch block without rethrowing.
- * g++.dg/eh/forced3.C: New.
- * g++.dg/eh/forced4.C: New.
+ PR c++/10570
+ * g++.dg/eh/forced1.C: Expect catch-all handlers to run.
+ Verify exception_cleanup not called for rethrows.
+ * g++.dg/eh/forced2.C: Test that exception_cleanup is called
+ when exiting catch block without rethrowing.
+ * g++.dg/eh/forced3.C: New.
+ * g++.dg/eh/forced4.C: New.
2003-05-07 Aldy Hernandez <aldyh@redhat.com>
diff --git a/gcc/testsuite/gcc.c-torture/execute/wchar_t-1.x b/gcc/testsuite/gcc.c-torture/execute/wchar_t-1.x
new file mode 100644
index 0000000..38c693d
--- /dev/null
+++ b/gcc/testsuite/gcc.c-torture/execute/wchar_t-1.x
@@ -0,0 +1,3 @@
+# Doesn't compile due to use of literal ISO8859.1 characters. PR 11439.
+set torture_compile_xfail "*-*-*"
+return 0
diff --git a/gcc/testsuite/gcc.dg/cpp/escape-2.c b/gcc/testsuite/gcc.dg/cpp/escape-2.c
index 31bf882..e79fa91 100644
--- a/gcc/testsuite/gcc.dg/cpp/escape-2.c
+++ b/gcc/testsuite/gcc.dg/cpp/escape-2.c
@@ -10,11 +10,11 @@
#if '\e' /* { dg-warning "non-ISO" "non-ISO \\e" } */
#endif
-#if '\u00a0' /* { dg-bogus "unknown" "\\u is known in C99" } */
+#if L'\u00a0' /* { dg-bogus "unknown" "\\u is known in C99" } */
#endif
void foo ()
{
int c = '\E'; /* { dg-warning "non-ISO" "non-ISO \\E" } */
- c = '\u00a0'; /* { dg-bogus "unknown" "\\u is known in C99" } */
+ c = L'\u00a0'; /* { dg-bogus "unknown" "\\u is known in C99" } */
}
diff --git a/gcc/testsuite/gcc.dg/cpp/escape.c b/gcc/testsuite/gcc.dg/cpp/escape.c
index 44ad4c1..c9dd44e 100644
--- a/gcc/testsuite/gcc.dg/cpp/escape.c
+++ b/gcc/testsuite/gcc.dg/cpp/escape.c
@@ -13,7 +13,7 @@
#if '\x1a' != 26 /* { dg-warning "traditional" "traditional hex" } */
#error bad hex /* { dg-bogus "bad" "bad hexadecimal evaluation" } */
#endif
-#if '\u' /* { dg-warning "unknown" "\u is unknown in C89" } */
+#if L'\u00a1' /* { dg-warning "only valid" "\u is unknown in C89" } */
#endif
void foo ()
@@ -21,5 +21,5 @@ void foo ()
int c = '\a'; /* { dg-warning "traditional" "traditional bell" } */
c = '\xa1'; /* { dg-warning "traditional" "traditional hex" } */
- c = '\u'; /* { dg-warning "unknown" "\u is unknown in C89" } */
+ c = L'\u00a1'; /* { dg-warning "only valid" "\u is unknown in C89" } */
}
diff --git a/gcc/testsuite/gcc.dg/cpp/ucs.c b/gcc/testsuite/gcc.dg/cpp/ucs.c
index d36e0dc..3f3d97e 100644
--- a/gcc/testsuite/gcc.dg/cpp/ucs.c
+++ b/gcc/testsuite/gcc.dg/cpp/ucs.c
@@ -35,12 +35,12 @@
#undef long
#if L'\u1234' != 0x1234
-#error bad short ucs /* { dg-bogus "bad" "bad \u1234 evaluation" } */
+#error bad short ucs /* { dg-bogus "bad" "bad u1234 evaluation" } */
#endif
#if WCHAR_MAX >= 0x7ffffff
# if L'\U1234abcd' != 0x1234abcd
-# error bad long ucs /* { dg-bogus "bad" "bad \U1234abcd evaluation" } */
+# error bad long ucs /* { dg-bogus "bad" "bad U1234abcd evaluation" } */
# endif
#endif
@@ -48,7 +48,7 @@ void foo ()
{
int c;
- c = L'\ubad'; /* { dg-error "incomplete" "incompete UCN 1" } */
+ c = L'\ubad'; /* { dg-error "incomplete" "incomplete UCN 1" } */
c = L"\U1234"[0]; /* { dg-error "incomplete" "incompete UCN 2" } */
c = L'\u000x'; /* { dg-error "incomplete" "non-hex digit in UCN" } */
@@ -58,7 +58,7 @@ void foo ()
c = '\u0024'; /* { dg-bogus "invalid" "0024 is a valid UCN" } */
c = "\u0040"[0]; /* { dg-bogus "invalid" "0040 is a valid UCN" } */
- c = '\u00a0'; /* { dg-bogus "invalid" "00a0 is a valid UCN" } */
+ c = L'\u00a0'; /* { dg-bogus "invalid" "00a0 is a valid UCN" } */
c = '\U00000060'; /* { dg-bogus "invalid" "0060 is a valid UCN" } */
c = '\u0025'; /* { dg-error "not a valid" "0025 invalid UCN" } */
diff --git a/gcc/testsuite/gcc.dg/wtr-strcat-1.c b/gcc/testsuite/gcc.dg/wtr-strcat-1.c
index b396652..730a929 100644
--- a/gcc/testsuite/gcc.dg/wtr-strcat-1.c
+++ b/gcc/testsuite/gcc.dg/wtr-strcat-1.c
@@ -9,7 +9,7 @@ testfunc ()
{
const char *foo;
- foo = "hello" "hello"; /* { dg-warning "string concatenation" "string concatenation" } */
+ foo = "hello" "hello"; /* { dg-warning "concatenation" "string concatenation" } */
# 15 "sys-header.h" 3
/* We are in system headers now, no -Wtraditional warnings should issue. */
diff --git a/gcc/testsuite/gcc.dg/concat.c b/gcc/testsuite/gcc.dg/concat.c
index 0a77b99..17a80a7 100644
--- a/gcc/testsuite/gcc.dg/concat.c
+++ b/gcc/testsuite/gcc.dg/concat.c
@@ -2,15 +2,15 @@
/* { dg-do compile } */
/* Test we output a warning for concatenation of artificial strings.
Neil Booth, 10 Dec 2001. */
void foo ()
{
- char str1[] = __FUNCTION__ "."; /* { dg-warning "deprecated" } */
- char str2[] = __PRETTY_FUNCTION__ ".";/* { dg-warning "deprecated" } */
- char str3[] = "." __FUNCTION__; /* { dg-warning "deprecated" } */
- char str4[] = "." __PRETTY_FUNCTION__;/* { dg-warning "deprecated" } */
- char str5[] = "." "."; /* No warning. */
+ char s1[] = __FUNCTION__"."; /* { dg-error "(parse|syntax|invalid)" } */
+ char s2[] = __PRETTY_FUNCTION__".";/* { dg-error "(parse|syntax|invalid)" } */
+ char s3[] = "."__FUNCTION__; /* { dg-error "(parse|syntax|invalid)" } */
+ char s4[] = "."__PRETTY_FUNCTION__;/* { dg-error "(parse|syntax|invalid)" } */
+ char s5[] = ".""."; /* No error. */
}
@@ -2,15 +2,15 @@
/* { dg-do compile } */
-/* Test we output a warning for concatenation of artificial strings.
+/* Test we output an error for concatenation of artificial strings.
Neil Booth, 10 Dec 2001. */
void foo ()